@@ -17,12 +17,13 @@ import requests
 # Import internal modules for setting up tracing and fetching pricing info.
 from opentelemetry import trace as t
 from opentelemetry.trace import SpanKind, Status, StatusCode, Span
-from openlit.semcov import SemanticConvetion
+from opentelemetry.sdk.resources import SERVICE_NAME, DEPLOYMENT_ENVIRONMENT
+from openlit.semcov import SemanticConvention
 from openlit.otel.tracing import setup_tracing
 from openlit.otel.metrics import setup_meter
+from openlit.otel.events import setup_events
 from openlit.__helpers import fetch_pricing_info, get_env_variable
 
-
 # Instrumentors for various large language models.
 from openlit.instrumentation.openai import OpenAIInstrumentor
 from openlit.instrumentation.anthropic import AnthropicInstrumentor
@@ -41,6 +42,7 @@ from openlit.instrumentation.premai import PremAIInstrumentor
 from openlit.instrumentation.assemblyai import AssemblyAIInstrumentor
 from openlit.instrumentation.azure_ai_inference import AzureAIInferenceInstrumentor
 from openlit.instrumentation.langchain import LangChainInstrumentor
+from openlit.instrumentation.langchain_community import LangChainCommunityInstrumentor
 from openlit.instrumentation.llamaindex import LlamaIndexInstrumentor
 from openlit.instrumentation.haystack import HaystackInstrumentor
 from openlit.instrumentation.embedchain import EmbedChainInstrumentor
@@ -64,6 +66,8 @@ from openlit.instrumentation.controlflow import ControlFlowInstrumentor
 from openlit.instrumentation.crawl4ai import Crawl4AIInstrumentor
 from openlit.instrumentation.firecrawl import FireCrawlInstrumentor
 from openlit.instrumentation.letta import LettaInstrumentor
+from openlit.instrumentation.openai_agents import OpenAIAgentsInstrumentor
+from openlit.instrumentation.pydantic_ai import PydanticAIInstrumentor
 from openlit.instrumentation.gpu import GPUInstrumentor
 import openlit.guard
 import openlit.evals
@@ -84,10 +88,11 @@ class OpenlitConfig:
         application_name (str): Name of the application using openLIT.
         pricing_info (Dict[str, Any]): Pricing information.
         tracer (Optional[Any]): Tracer instance for OpenTelemetry.
+        event_provider (Optional[Any]): Event logger provider for OpenTelemetry.
         otlp_endpoint (Optional[str]): Endpoint for OTLP.
         otlp_headers (Optional[Dict[str, str]]): Headers for OTLP.
         disable_batch (bool): Flag to disable batch span processing in tracing.
-        trace_content (bool): Flag to enable or disable tracing of content.
+        capture_message_content (bool): Flag to enable or disable tracing of content.
     """
 
     _instance = None
@@ -106,11 +111,12 @@ class OpenlitConfig:
         cls.application_name = "default"
         cls.pricing_info = {}
         cls.tracer = None
+        cls.event_provider = None
         cls.metrics_dict = {}
         cls.otlp_endpoint = None
         cls.otlp_headers = None
         cls.disable_batch = False
-        cls.trace_content = True
+        cls.capture_message_content = True
         cls.disable_metrics = False
 
     @classmethod
@@ -119,10 +125,11 @@ class OpenlitConfig:
         environment,
         application_name,
         tracer,
+        event_provider,
         otlp_endpoint,
         otlp_headers,
         disable_batch,
-        trace_content,
+        capture_message_content,
         metrics_dict,
         disable_metrics,
         pricing_json,
@@ -134,24 +141,29 @@ class OpenlitConfig:
             environment (str): Deployment environment.
             application_name (str): Application name.
             tracer: Tracer instance.
+            event_provider: Event logger provider instance.
             meter: Metric Instance
             otlp_endpoint (str): OTLP endpoint.
             otlp_headers (Dict[str, str]): OTLP headers.
             disable_batch (bool): Disable batch span processing flag.
-            trace_content (bool): Enable or disable content tracing.
+            capture_message_content (bool): Enable or disable content tracing.
+            metrics_dict: Dictionary of metrics.
+            disable_metrics (bool): Flag to disable metrics.
             pricing_json(str): path or url to the pricing json file
         """
         cls.environment = environment
         cls.application_name = application_name
         cls.pricing_info = fetch_pricing_info(pricing_json)
         cls.tracer = tracer
+        cls.event_provider = event_provider
         cls.metrics_dict = metrics_dict
         cls.otlp_endpoint = otlp_endpoint
         cls.otlp_headers = otlp_headers
         cls.disable_batch = disable_batch
-        cls.trace_content = trace_content
+        cls.capture_message_content = capture_message_content
         cls.disable_metrics = disable_metrics
 
+
 def module_exists(module_name):
     """Check if nested modules exist, addressing the dot notation issue."""
     parts = module_name.split(".")
@@ -160,6 +172,7 @@ def module_exists(module_name):
             return False
     return True
 
+
 def instrument_if_available(
     instrumentor_name,
     instrumentor_instance,
@@ -184,21 +197,38 @@ def instrument_if_available(
                 environment=config.environment,
                 application_name=config.application_name,
                 tracer=config.tracer,
+                event_provider=config.event_provider,
                 pricing_info=config.pricing_info,
-                trace_content=config.trace_content,
+                capture_message_content=config.capture_message_content,
                 metrics_dict=config.metrics_dict,
                 disable_metrics=config.disable_metrics,
             )
         else:
             # pylint: disable=line-too-long
-            logger.info("Library for %s (%s) not found. Skipping instrumentation", instrumentor_name, module_name)
+            logger.info(
+                "Library for %s (%s) not found. Skipping instrumentation",
+                instrumentor_name,
+                module_name,
+            )
     except Exception as e:
         logger.error("Failed to instrument %s: %s", instrumentor_name, e)
 
 
-def init(environment="default", application_name="default", tracer=None, otlp_endpoint=None,
-         otlp_headers=None, disable_batch=False, trace_content=True, disabled_instrumentors=None,
-         meter=None, disable_metrics=False, pricing_json=None, collect_gpu_stats=False):
+def init(
+    environment="default",
+    application_name="default",
+    tracer=None,
+    event_logger=None,
+    otlp_endpoint=None,
+    otlp_headers=None,
+    disable_batch=False,
+    capture_message_content=True,
+    disabled_instrumentors=None,
+    meter=None,
+    disable_metrics=False,
+    pricing_json=None,
+    collect_gpu_stats=False,
+):
     """
     Initializes the openLIT configuration and setups tracing.
 
@@ -209,11 +239,12 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
         environment (str): Deployment environment.
         application_name (str): Application name.
         tracer: Tracer instance (Optional).
+        event_logger: EventLoggerProvider instance (Optional).
         meter: OpenTelemetry Metrics Instance (Optional).
         otlp_endpoint (str): OTLP endpoint for exporter (Optional).
         otlp_headers (Dict[str, str]): OTLP headers for exporter (Optional).
         disable_batch (bool): Flag to disable batch span processing (Optional).
-        trace_content (bool): Flag to trace content (Optional).
+        capture_message_content (bool): Flag to trace content (Optional).
         disabled_instrumentors (List[str]): Optional. List of instrumentor names to disable.
         disable_metrics (bool): Flag to disable metrics (Optional).
         pricing_json(str): File path or url to the pricing json (Optional).
@@ -234,9 +265,10 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
         "gpt4all": "gpt4all",
         "elevenlabs": "elevenlabs",
         "vllm": "vllm",
-        "google-ai-studio": "google.generativeai",
+        "google-ai-studio": "google.genai",
         "azure-ai-inference": "azure.ai.inference",
         "langchain": "langchain",
+        "langchain_community": "langchain_community",
         "llama_index": "llama_index",
         "haystack": "haystack",
         "embedchain": "embedchain",
@@ -265,13 +297,17 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
         "firecrawl": "firecrawl",
         "letta": "letta",
         "together": "together",
+        "openai-agents": "agents",
+        "pydantic_ai": "pydantic_ai"
     }
 
     invalid_instrumentors = [
         name for name in disabled_instrumentors if name not in module_name_map
     ]
     for invalid_name in invalid_instrumentors:
-        logger.warning("Invalid instrumentor name detected and ignored: '%s'", invalid_name)
+        logger.warning(
+            "Invalid instrumentor name detected and ignored: '%s'", invalid_name
+        )
 
     try:
         # Retrieve or create the single configuration instance.
@@ -288,9 +324,22 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
         )
 
         if not tracer:
-            logger.error("openLIT tracing setup failed. Tracing will not be available.")
+            logger.error("OpenLIT tracing setup failed. Tracing will not be available.")
             return
 
+        # Setup events based on the provided or default configuration.
+        event_provider = setup_events(
+                application_name=application_name,
+                environment=environment,
+                event_logger=event_logger,
+                otlp_endpoint=None,
+                otlp_headers=None,
+                disable_batch=disable_batch,
+            )
+
+        if not event_provider:
+            logger.error("OpenLIT events setup failed. Events will not be available")
+
         # Setup meter and receive metrics_dict instead of meter.
         metrics_dict, err = setup_meter(
             application_name=application_name,
@@ -301,18 +350,24 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
         )
 
         if err:
-            logger.error("OpenLIT metrics setup failed. Metrics will not be available: %s", err)
+            logger.error(
+                "OpenLIT metrics setup failed. Metrics will not be available: %s", err
+            )
             return
 
+        if os.getenv("OTEL_INSTRUMENTATION_GENAI_CAPTURE_MESSAGE_CONTENT", "").lower == "false":
+            capture_message_content=False
+
         # Update global configuration with the provided settings.
         config.update_config(
             environment,
             application_name,
             tracer,
+            event_provider,
             otlp_endpoint,
             otlp_headers,
             disable_batch,
-            trace_content,
+            capture_message_content,
             metrics_dict,
             disable_metrics,
             pricing_json,
@@ -334,6 +389,7 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
             "google-ai-studio": GoogleAIStudioInstrumentor(),
             "azure-ai-inference": AzureAIInferenceInstrumentor(),
             "langchain": LangChainInstrumentor(),
+            "langchain_community": LangChainCommunityInstrumentor(),
             "llama_index": LlamaIndexInstrumentor(),
             "haystack": HaystackInstrumentor(),
             "embedchain": EmbedChainInstrumentor(),
@@ -362,12 +418,15 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
             "firecrawl": FireCrawlInstrumentor(),
             "letta": LettaInstrumentor(),
             "together": TogetherInstrumentor(),
+            "openai-agents": OpenAIAgentsInstrumentor(),
+            "pydantic_ai": PydanticAIInstrumentor(),
         }
 
         # Initialize and instrument only the enabled instrumentors
         for name, instrumentor in instrumentor_instances.items():
-            instrument_if_available(name, instrumentor, config,
-            disabled_instrumentors, module_name_map)
+            instrument_if_available(
+                name, instrumentor, config, disabled_instrumentors, module_name_map
+            )
 
         if not disable_metrics and collect_gpu_stats:
             GPUInstrumentor().instrument(
@@ -377,24 +436,33 @@ def init(environment="default", application_name="default", tracer=None, otlp_en
     except Exception as e:
         logger.error("Error during openLIT initialization: %s", e)
 
-def get_prompt(url=None, name=None, api_key=None, prompt_id=None,
-    version=None, should_compile=None, variables=None, meta_properties=None):
+
+def get_prompt(
+    url=None,
+    name=None,
+    api_key=None,
+    prompt_id=None,
+    version=None,
+    should_compile=None,
+    variables=None,
+    meta_properties=None,
+):
     """
     Retrieve and returns the prompt from OpenLIT Prompt Hub
     """
 
     # Validate and set the base URL
     url = get_env_variable(
-        'OPENLIT_URL',
+        "OPENLIT_URL",
         url,
-        'Missing OpenLIT URL: Provide as arg or set OPENLIT_URL env var.'
+        "Missing OpenLIT URL: Provide as arg or set OPENLIT_URL env var.",
     )
 
     # Validate and set the API key
     api_key = get_env_variable(
-        'OPENLIT_API_KEY', 
+        "OPENLIT_API_KEY",
         api_key,
-        'Missing API key: Provide as arg or set OPENLIT_API_KEY env var.'
+        "Missing API key: Provide as arg or set OPENLIT_API_KEY env var.",
     )
 
     # Construct the API endpoint
@@ -402,23 +470,20 @@ def get_prompt(url=None, name=None, api_key=None, prompt_id=None,
 
     # Prepare the payload
     payload = {
-        'name': name,
-        'promptId': prompt_id,
-        'version': version,
-        'shouldCompile': should_compile,
-        'variables': variables,
-        'metaProperties': meta_properties,
-        'source': 'python-sdk'
+        "name": name,
+        "promptId": prompt_id,
+        "version": version,
+        "shouldCompile": should_compile,
+        "variables": variables,
+        "metaProperties": meta_properties,
+        "source": "python-sdk",
     }
 
     # Remove None values from payload
     payload = {k: v for k, v in payload.items() if v is not None}
 
     # Prepare headers
-    headers = {
-        'Authorization': f'Bearer {api_key}',
-        'Content-Type': 'application/json'
-    }
+    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
 
     try:
         # Make the POST request to the API with headers
@@ -433,6 +498,7 @@ def get_prompt(url=None, name=None, api_key=None, prompt_id=None,
         logger.error("Error fetching prompt: '%s'", error)
         return None
 
+
 def get_secrets(url=None, api_key=None, key=None, tags=None, should_set_env=None):
     """
     Retrieve & returns the secrets from OpenLIT Vault & sets all to env is should_set_env is True
@@ -440,36 +506,29 @@ def get_secrets(url=None, api_key=None, key=None, tags=None, should_set_env=None
 
     # Validate and set the base URL
     url = get_env_variable(
-        'OPENLIT_URL',
+        "OPENLIT_URL",
         url,
-        'Missing OpenLIT URL: Provide as arg or set OPENLIT_URL env var.'
+        "Missing OpenLIT URL: Provide as arg or set OPENLIT_URL env var.",
     )
 
     # Validate and set the API key
     api_key = get_env_variable(
-        'OPENLIT_API_KEY', 
+        "OPENLIT_API_KEY",
         api_key,
-        'Missing API key: Provide as arg or set OPENLIT_API_KEY env var.'
+        "Missing API key: Provide as arg or set OPENLIT_API_KEY env var.",
     )
 
     # Construct the API endpoint
     endpoint = url + "/api/vault/get-secrets"
 
     # Prepare the payload
-    payload = {
-        'key': key,
-        'tags': tags,
-        'source': 'python-sdk'
-    }
+    payload = {"key": key, "tags": tags, "source": "python-sdk"}
 
     # Remove None values from payload
     payload = {k: v for k, v in payload.items() if v is not None}
 
     # Prepare headers
-    headers = {
-        'Authorization': f'Bearer {api_key}',
-        'Content-Type': 'application/json'
-    }
+    headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
 
     try:
         # Make the POST request to the API with headers
@@ -481,7 +540,7 @@ def get_secrets(url=None, api_key=None, key=None, tags=None, should_set_env=None
         # Return the JSON response
         vault_response = response.json()
 
-        res = vault_response.get('res', [])
+        res = vault_response.get("res", [])
 
         if should_set_env is True:
             for token, value in res.items():
@@ -491,43 +550,54 @@ def get_secrets(url=None, api_key=None, key=None, tags=None, should_set_env=None
         logger.error("Error fetching secrets: '%s'", error)
         return None
 
+
 def trace(wrapped):
     """
     Generates a telemetry wrapper for messages to collect metrics.
     """
+    if not callable(wrapped):
+        raise TypeError(
+            f"@trace can only be applied to callable objects, got {type(wrapped).__name__}"
+        )
+
+    try:
+        __trace = t.get_tracer_provider()
+        tracer = __trace.get_tracer(__name__)
+    except Exception as tracer_exception:
+        logging.error(
+            "Failed to initialize tracer: %s", tracer_exception, exc_info=True
+        )
+        raise
 
     @wraps(wrapped)
     def wrapper(*args, **kwargs):
-        __trace = t.get_tracer_provider()
-        with __trace.get_tracer(__name__).start_as_current_span(
+        with tracer.start_as_current_span(
             name=wrapped.__name__,
             kind=SpanKind.CLIENT,
         ) as span:
+            response = None
             try:
                 response = wrapped(*args, **kwargs)
                 span.set_attribute(
-                    SemanticConvetion.GEN_AI_CONTENT_COMPLETION, response
+                    SemanticConvention.GEN_AI_CONTENT_COMPLETION, response or ""
                 )
                 span.set_status(Status(StatusCode.OK))
-
             except Exception as e:
-                response = None
                 span.record_exception(e)
-                span.set_status(status=Status(StatusCode.ERROR), description=e)
+                span.set_status(status=Status(StatusCode.ERROR), description=str(e))
                 logging.error("Error in %s: %s", wrapped.__name__, e, exc_info=True)
+                raise
 
-            # Adding function arguments as metadata
             try:
                 span.set_attribute("function.args", str(args))
                 span.set_attribute("function.kwargs", str(kwargs))
                 span.set_attribute(
-                    SemanticConvetion.GEN_AI_APPLICATION_NAME,
+                    SERVICE_NAME,
                     OpenlitConfig.application_name,
                 )
                 span.set_attribute(
-                    SemanticConvetion.GEN_AI_ENVIRONMENT, OpenlitConfig.environment
+                    DEPLOYMENT_ENVIRONMENT, OpenlitConfig.environment
                 )
-
             except Exception as meta_exception:
                 logging.error(
                     "Failed to set metadata for %s: %s",
@@ -568,7 +638,7 @@ class TracedSpan:
             result: The result to be set as an attribute on the span.
         """
 
-        self._span.set_attribute(SemanticConvetion.GEN_AI_CONTENT_COMPLETION, result)
+        self._span.set_attribute(SemanticConvention.GEN_AI_CONTENT_COMPLETION, result)
 
     def set_metadata(self, metadata: Dict):
         """
