@@ -1,4 +1,3 @@
-# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
 """Initializer of Auto Instrumentation of AssemblyAI Functions"""
 
 from typing import Collection
@@ -6,15 +5,13 @@ import importlib.metadata
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from wrapt import wrap_function_wrapper
 
-from openlit.instrumentation.assemblyai.assemblyai import (
-    transcribe
-)
+from openlit.instrumentation.assemblyai.assemblyai import transcribe
 
 _instruments = ("assemblyai >= 0.35.1",)
 
 class AssemblyAIInstrumentor(BaseInstrumentor):
     """
-    An instrumentor for AssemblyAI's client library.
+    An instrumentor for AssemblyAI client library.
     """
 
     def instrumentation_dependencies(self) -> Collection[str]:
@@ -26,7 +23,7 @@ class AssemblyAIInstrumentor(BaseInstrumentor):
         tracer = kwargs.get("tracer")
         metrics = kwargs.get("metrics_dict")
         pricing_info = kwargs.get("pricing_info", {})
-        trace_content = kwargs.get("trace_content", False)
+        capture_message_content = kwargs.get("capture_message_content", False)
         disable_metrics = kwargs.get("disable_metrics")
         version = importlib.metadata.version("assemblyai")
 
@@ -34,10 +31,9 @@ class AssemblyAIInstrumentor(BaseInstrumentor):
         wrap_function_wrapper(
             "assemblyai.transcriber",
             "Transcriber.transcribe",
-            transcribe("assemblyai.transcribe", version, environment, application_name,
-                  tracer, pricing_info, trace_content, metrics, disable_metrics),
+            transcribe(version, environment, application_name,
+                  tracer, pricing_info, capture_message_content, metrics, disable_metrics),
         )
 
     def _uninstrument(self, **kwargs):
-        # Proper uninstrumentation logic to revert patched methods
         pass
